### libnpyrandom

This is a vendored version of NumPy's sources for `libnpyrandom`, with only the
routines necessary for use in `scipy.stats` included. The vendored code is pure
C, it doesn't depend on either NumPy or Python.
